slepc-3.18.0 2022-10-01
Report Typos and Errors

# STApplyMat

Applies the spectral transformation operator to a matrix, for instance (A - sB)^-1 B in the case of the shift-and-invert transformation and generalized eigenproblem.

### Synopsis

    #include "slepcst.h"
    PetscErrorCode STApplyMat(ST st,Mat X,Mat Y)

Collective on st

### Input Parameters

| st | - the spectral transformation context
| X | - input matrix

### Output Parameter

| Y | - output matrix

### See Also

STApply()

### Level

developer

### Location

src/sys/classes/st/interface/stsolve.c
Index of all ST routines
Table of Contents for all manual pages
Index of all manual pages